package dev.theolm.bugsample

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Surface
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.runtime.rememberCoroutineScope
import androidx.compose.ui.Modifier
import androidx.compose.ui.tooling.preview.Preview
import cafe.adriel.voyager.core.screen.Screen
import cafe.adriel.voyager.navigator.Navigator
import dev.theolm.bugsample.ui.FirstScreen
import dev.theolm.bugsample.ui.theme.BugsampleTheme
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.launch


private val screenStackFlow = MutableStateFlow<List<Screen>>(listOf(FirstScreen()))

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContent {
            BugsampleTheme {
                AppRoot()
            }
        }
    }
}

@Composable
fun AppRoot() {
    val screenStack by screenStackFlow.collectAsState()

    LaunchedEffect(screenStack) {
        println("screenStack state changed: $screenStack")
    }

    Surface(
        modifier = Modifier.fillMaxSize(),
        color = MaterialTheme.colorScheme.background
    ) {
        Navigator(screens = screenStack)
    }
}

fun replaceStack(newStack : List<Screen>) {
    println("newStack emitted: $newStack")
    screenStackFlow.tryEmit(newStack)
}